import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
import React from 'react';
import cx from 'classnames';
var MAX_LABEL_LENGTH = 100;
var TRANSPARENT = 'transparent';
var SIZES = {
  LARGE: 'large',
  MEDIUM: 'medium',
  SMALL: 'small'
};
var TYPES = {
  SUCCESS: 'success',
  ERROR: 'error',
  INFO: 'info',
  ALERT: 'alert',
  NEW: 'new',
  NEUTRAL: 'neutral',
  PRIMARY: 'primary'
};
export var DESIGNS = {
  SOLID: 'solid',
  SOFT: 'soft'
};
var BASE_CLASS = "sui-AtomBadge";
var CLASS_ICON = BASE_CLASS + "-icon";
var CLASS_ICON_RIGHT = CLASS_ICON + "--iconRight";
var CLASS_TEXT = CLASS_ICON + "-text";
/**
 * Cuts off exceeded char limit
 * @param  {string} label
 * @return {string}
 */

var truncateText = function truncateText(label) {
  return label.length < MAX_LABEL_LENGTH ? label : label.substr(0, MAX_LABEL_LENGTH);
};
/**
 * @param  {object} options
 * @param  {string} options.size
 * @param  {boolean} options.transparent
 * @param  {object} options.iconRight
 * @param  {string} options.type
 * @return {string}
 */


var getClassNames = function getClassNames(_ref) {
  var _cx;

  var design = _ref.design,
      iconRight = _ref.iconRight,
      size = _ref.size,
      transparent = _ref.transparent,
      type = _ref.type;
  var transparentClass = transparent && "--" + TRANSPARENT || '';
  return cx(BASE_CLASS, BASE_CLASS + "-" + size, BASE_CLASS + "-" + type + transparentClass, design && BASE_CLASS + "-" + type + "--" + design, (_cx = {}, _cx[CLASS_ICON_RIGHT] = iconRight, _cx));
};
/**
 * Small badges with background can't have icon
 * @param  {Object} options
 * @param  {Object} options.icon
 * @param  {string} options.size
 * @param  {boolean} options.transparent
 * @return {boolean}
 */


var shouldRenderIcon = function shouldRenderIcon(_ref2) {
  var icon = _ref2.icon,
      size = _ref2.size,
      transparent = _ref2.transparent;
  return icon && (size !== SIZES.SMALL || transparent);
};

var AtomBadge = function AtomBadge(_ref3) {
  var icon = _ref3.icon,
      iconRight = _ref3.iconRight,
      label = _ref3.label,
      props = _objectWithoutPropertiesLoose(_ref3, ["icon", "iconRight", "label"]);

  var truncatedLabel = truncateText(label);
  var classNames = getClassNames(props);
  return /*#__PURE__*/_jsxs("div", {
    className: classNames,
    children: [shouldRenderIcon(_extends({
      icon: icon
    }, props)) && !iconRight && /*#__PURE__*/_jsx("span", {
      className: CLASS_ICON,
      children: icon
    }), /*#__PURE__*/_jsx("span", {
      className: CLASS_TEXT,
      title: truncatedLabel,
      children: label
    }), shouldRenderIcon(_extends({
      icon: icon
    }, props)) && iconRight && /*#__PURE__*/_jsx("span", {
      className: cx(CLASS_ICON, CLASS_ICON_RIGHT),
      children: icon
    })]
  });
};

AtomBadge.displayName = 'AtomBadge';
AtomBadge.defaultProps = {
  size: SIZES.SMALL,
  type: TYPES.SUCCESS
};
export default AtomBadge;
export { DESIGNS as atomBadgeDesigns, TYPES as atomBadgeTypes, SIZES as atomBadgeSizes };